Documentation
¶
Index ¶
- Variables
- type ClickDeb
- func (d *ClickDeb) Build(sourceDir string, dataTarFinishedCallback func(dataName string) error) error
- func (d *ClickDeb) Close() error
- func (d *ClickDeb) ControlMember(controlMember string) (content []byte, err error)
- func (d *ClickDeb) MetaMember(metaMember string) (content []byte, err error)
- func (d *ClickDeb) Name() string
- func (d *ClickDeb) Unpack(targetDir string) error
Constants ¶
This section is empty.
Variables ¶
var ( // ErrSnapInvalidContent is returned if a snap package contains // invalid content ErrSnapInvalidContent = errors.New("snap contains invalid content") )
Functions ¶
This section is empty.
Types ¶
type ClickDeb ¶
type ClickDeb struct {
// contains filtered or unexported fields
}
ClickDeb provides support for the "click" containers (a special kind of deb package)
func (*ClickDeb) Build ¶
func (d *ClickDeb) Build(sourceDir string, dataTarFinishedCallback func(dataName string) error) error
Build takes a build debian directory with DEBIAN/ dir and creates a clickdeb from it
func (*ClickDeb) ControlMember ¶
ControlMember returns the content of the given control member file (e.g. the content of the "manifest" file in the control.tar.gz ar member)
func (*ClickDeb) MetaMember ¶
MetaMember returns the content of the given meta file (e.g. the content of the "package.yaml" file) from the data.tar.gz ar member's meta/ directory
Click to show internal directories.
Click to hide internal directories.